Warning : Warning returned when the request is successful, but there are important callouts based on which API clients should take defined actions.
Fields
code: StringAn warning code that identifies the type of warning that occurred.
message: StringA message that describes the warning condition in a human-readable form.
details: Option<String>Additional details that can help the caller understand or address the warning.
Implementations